@@ -1,7 +1,7 @@
 package App::FilterOrgByHeadlines;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010;
 use strict;
@@ -253,7 +253,7 @@ App::FilterOrgByHeadlines - Filter Org by headlines
 
 =head1 VERSION
 
-This document describes version 0.28 of App::FilterOrgByHeadlines (from Perl distribution App-OrgUtils), released on 2015-04-01.
+This document describes version 0.29 of App::FilterOrgByHeadlines (from Perl distribution App-OrgUtils), released on 2015-04-02.
 
 =head1 FUNCTIONS
 
@@ -321,15 +321,20 @@ Return value:  (str)
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.=head1 SOURCE
+Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.
 
-Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.=head1 BUGS
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
+
+=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-OrgUtils>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
