@@ -1,7 +1,7 @@
 package App::ListOrgAnniversaries;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010;
 use strict;
@@ -215,7 +215,7 @@ sub list_org_anniversaries {
 
     my $sort  = $args{sort};
     my $tz    = $args{time_zone} // $ENV{TZ} // "UTC";
-    my $files = $args{file};
+    my $files = $args{files};
     my $f     = $args{field_pattern} // '';
     return [400, "Invalid field_pattern: $@"] unless eval { $f = qr/$f/i };
     $args{field_pattern} = $f;
@@ -271,7 +271,7 @@ App::ListOrgAnniversaries - List all anniversaries in Org files
 
 =head1 VERSION
 
-This document describes version 0.28 of App::ListOrgAnniversaries (from Perl distribution App-OrgUtils), released on 2015-04-01.
+This document describes version 0.29 of App::ListOrgAnniversaries (from Perl distribution App-OrgUtils), released on 2015-04-02.
 
 =head1 SYNOPSIS
 
@@ -331,7 +331,7 @@ Only show anniversaries that are due in this number of days.
 
 Field regex that specifies anniversaries.
 
-=item * B<file>* => I<array[str]>
+=item * B<files>* => I<array[str]>
 
 =item * B<has_tags> => I<array[str]>
 
@@ -383,15 +383,20 @@ Return value:  (any)
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.=head1 SOURCE
+Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.
 
-Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.=head1 BUGS
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
+
+=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-OrgUtils>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
