@@ -1,7 +1,7 @@
 package App::ListOrgHeadlines;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010001;
 use strict;
@@ -317,7 +317,7 @@ sub list_org_headlines {
 
     my $sort  = $args{sort};
     my $tz    = $args{time_zone} // $ENV{TZ} // "UTC";
-    my $files = $args{file};
+    my $files = $args{files};
 
     $today = $args{today} // DateTime->today(time_zone => $tz);
 
@@ -398,7 +398,7 @@ App::ListOrgHeadlines - List all headlines in all Org files
 
 =head1 VERSION
 
-This document describes version 0.28 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2015-04-01.
+This document describes version 0.29 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2015-04-02.
 
 =head1 SYNOPSIS
 
@@ -447,7 +447,7 @@ if today is 2011-06-30 and due_in is set to 7, then todo item with due date
 than 7) but <2011-07-10 Sun +1y -14d> will (warning period 14 days is already
 passed by that time).
 
-=item * B<file>* => I<array[str]>
+=item * B<files>* => I<array[str]>
 
 =item * B<from_level> => I<int> (default: 1)
 
@@ -548,15 +548,20 @@ Return value:  (any)
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.=head1 SOURCE
+Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.
 
-Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.=head1 BUGS
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
+
+=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-OrgUtils>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
