@@ -1,7 +1,7 @@
 package App::OrgUtils;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010;
 use strict;
@@ -11,12 +11,13 @@ use Log::Any '$log';
 use Org::Parser;
 
 our %common_args1 = (
-    file => {
+    files => {
         schema => ['array*' => of => 'str*', min_len=>1],
         req    => 1,
         pos    => 0,
         greedy => 1,
         'x.schema.element_entity' => 'filename',
+        'x.name.is_plural' => 1,
     },
     cache_dir => {
         schema => ['str*'],
@@ -58,10 +59,10 @@ our $_complete_state = sub {
     my $args = $res->[2];
 
     # read org
-    return unless $args->{file} && @{ $args->{file} };
+    return unless $args->{files} && @{ $args->{files} };
     my $tz = $args->{time_zone} // $ENV{TZ} // "UTC";
     my %docs = App::OrgUtils::_load_org_files_with_cache(
-        [grep {-f} @{ $args->{file} }], $args->{cache_dir}, {time_zone=>$tz});
+        [grep {-f} @{ $args->{files} }], $args->{cache_dir}, {time_zone=>$tz});
 
     # get todo states
     my @states;
@@ -90,10 +91,10 @@ our $_complete_priority = sub {
     my $args = $res->[2];
 
     # read org
-    return unless $args->{file} && @{ $args->{file} };
+    return unless $args->{files} && @{ $args->{files} };
     my $tz = $args->{time_zone} // $ENV{TZ} // "UTC";
     my %docs = App::OrgUtils::_load_org_files_with_cache(
-        [grep {-f} @{ $args->{file} }], $args->{cache_dir}, {time_zone=>$tz});
+        [grep {-f} @{ $args->{files} }], $args->{cache_dir}, {time_zone=>$tz});
 
     # get priorities
     my @prios;
@@ -122,10 +123,10 @@ our $_complete_tags = sub {
     my $args = $res->[2];
 
     # read org
-    return unless $args->{file} && @{ $args->{file} };
+    return unless $args->{files} && @{ $args->{files} };
     my $tz = $args->{time_zone} // $ENV{TZ} // "UTC";
     my %docs = App::OrgUtils::_load_org_files_with_cache(
-        [grep {-f} @{ $args->{file} }], $args->{cache_dir}, {time_zone=>$tz});
+        [grep {-f} @{ $args->{files} }], $args->{cache_dir}, {time_zone=>$tz});
 
     # collect tags
     my @tags;
@@ -187,7 +188,7 @@ App::OrgUtils - Some utilities for Org documents
 
 =head1 VERSION
 
-This document describes version 0.28 of App::OrgUtils (from Perl distribution App-OrgUtils), released on 2015-04-01.
+This document describes version 0.29 of App::OrgUtils (from Perl distribution App-OrgUtils), released on 2015-04-02.
 
 =head1 DESCRIPTION
 
@@ -200,15 +201,20 @@ L<Org::Parser>
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.=head1 SOURCE
+Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.
 
-Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.=head1 BUGS
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
+
+=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-OrgUtils>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
